==> ksensors_0.5.orig.tar.gz: ksensors-0.5/ksensors/lmsensorscfg.h <==
/***************************************************************************
                          lmsensorscfg.h  -  description
                             -------------------
    begin                : Mon Aug 13 2001
    copyright            : (C) 2001 by Miguel Novas
    email                : michaell@teleline.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LMSENSORSCFG_H
#define LMSENSORSCFG_H

#include <qobject.h>

#include "lmsensors.h"
#include "lmsensorscfgdesign.h"

/**
  *@author 
  */

class LMSensorsCfg : public LMSensorsCfgDesign  {
Q_OBJECT
public:
	LMSensorsCfg(LMSensors *lsensors,QWidget *parent=0, const char *name=0);
	~LMSensorsCfg();

signals:

  void itemShowChanged(const char *name);
  void itemAlarmChanged(const char *name);
  void itemDockChanged(const char *name);
  void systemUpdateIntervalChanged();

protected slots:

  void slotAccept();
  void slotApplyChanges();

  void slotTestAlarm();
  void slotCurrentSensorChanged(int index);

  void slotMainTabPageChanged(QWidget *);
  void slotComboMinMaxSelected(int index);

protected:

  void applySensorChanges();
  void applySystemInfoChanges();
  void applyPreferencesChanges();
  void applySensorAlarmConfig(KConfig *cfg, const char *name);

  void readSensorInfo(int index);
  void readSystemInfo();
  void readPreferencesInfo();

private:

  LMSensors *sensors;
  LMSensor  *curSensor;
  int        indexCurSensor;

  void applyOneSystemInfoItem(KConfig *cfg, QCheckBox *check,const char *name);
};

#endif

==> ksensors_0.7.2.orig.tar.gz: ksensors-0.7.2/ksensors/lmsensorscfg.h <==
/***************************************************************************
                          lmsensorscfg.h  -  description
                             -------------------
    begin                : Mon Aug 13 2001
    copyright            : (C) 2001 by Miguel Novas
    email                : michaell@teleline.es
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef LMSENSORSCFG_H
#define LMSENSORSCFG_H

//#include <qobject.h>

#include "sensorslist.h"
#include "lmsensorscfgdesign.h"
#include "palettecfg.h"

/**
  *@author 
  */

class LMSensorsCfg : public LMSensorsCfgDesign  {
Q_OBJECT
public:
	LMSensorsCfg(SensorsList *lsensors,QWidget *parent=0, const char *name=0);
	~LMSensorsCfg();

protected slots:

  void slotAccept();
  void slotApplyChanges();

  void slotTestAlarm();
  void slotCurrentSensorChanged(int index);

  void slotMainTabPageChanged(QWidget *);
  void slotComboMinMaxSelected(int index);

protected:

  void applySensorChanges();
  void applyPreferencesChanges();
  void applySensorAlarmConfig(Sensor *sensor);

  void readSensorInfo(int index);
  void readPreferencesInfo();
  void readSensorsList();

private:

  PaletteCfg *palPanelCfg;

  SensorsList *sensors;
  Sensor      *curSensor;
};

#endif
